nm_dict_list=[
  {
    "model": "2x40G",
    "supported: "yes",
    "description": ""
  },
  {
    "model": "4x10G",
    "supported: "yes",
    "description": ""
  },
  {
    "model": "8x10G",
    "supported: "yes",
    "description": ""
  },
  {
    "model": "C3850-NM-2-10G",
    "supported: "no",
    "description": "Catalyst 3850 4 x Gigabit Ethernet/2 x 10 Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-2-40G",
    "supported: "yes",
    "description": "Catalyst 3850 2 x 40 Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-4-1G",
    "supported: "yes",
    "description": "Catalyst 3850 4 x Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-4-10G",
    "supported: "yes",
    "description": "Catalyst 3850 4 x Gigabit Ethernet/4 x 10 Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-8-10G",
    "supported: "yes",
    "description": "Catalyst 3850 8 x Gigabit Ethernet/8 x 10 Gigabit Ethernet Network Module"
  },
  {
    "model": "C9300-NM-2C",
    "supported: "yes",
    "description": "Catalyst 9300 2 x 100G/40G dual rate QSFP Network Module"
  },
  {
    "model": "C9300-NM-2Q",
    "supported: "yes",
    "description": "Catalyst 9300 2 x 40GE QSFP Network Module"
  },
  {
    "model": "C9300-NM-2Y",
    "supported: "yes",
    "description": "Catalyst 9300 2 x 25G/10G/1G SFP28 Network Module"
  },
  {
    "model": "C9300-NM-4C",
    "supported: "yes",
    "description": "Catalyst 9300 4 x 100G/40G dual rate QSFP Network Module"
  },
  {
    "model": "C9300-NM-4G",
    "supported: "yes",
    "description": "Catalyst 9300 4 x 1GE SFP Network Module"
  },
  {
    "model": "C9300-NM-4M",
    "supported: "yes",
    "description": "Catalyst 9300 4 x 10G/mGig copper Network Module"
  },
  {
    "model": "C9300-NM-8M",
    "supported: "yes",
    "description": "Catalyst 9300X 8 x 10G/mGig copper Network Module"
  },
  {
    "model": "C9300-NM-8X",
    "supported: "yes",
    "description": "Catalyst 9300 8 x 10G/1G SFP+ Network Module"
  },
  {
    "model": "C9300-NM-8Y",
    "supported: "yes",
    "description": "Catalyst 9300 8 x 25G/10G/1G multi-rate SFP Network Module"
  }
]