# Do you want a ton of debug output on the console?
DEBUG = False # ALL DEBUGS
DEBUG_MAIN = False
DEBUG_TRANSLATOR = False
DEBUG_CHECKER = False
DEBUG_REGISTER = False
DEBUG_CLAIM = False
DEBUG_SPLIT = False
DEBUG_FILE = False

# So you want a PDF report generated from the DOCX report (requires MS Word)
PDF = False

# For ngrok to create a web proxy tunnel for the bot
NGROK_AUTHTOKEN = "er9usadfj2349uwdfhusdjadu324hjwwdfjksdfu92348ywdf"

# For netmiko to connect to a switch directly
IOS_USERNAME = 'admin'
IOS_PASSWORD = 'password'
IOS_SECRET = 'secret'
IOS_PORT = 22

# Webex Teams Bot Access Token for this Bot 
TEAMS_TOKEN = "ZTZjMDc5ZTUtN2Q5NS00NzNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN2_PF84_1eb65fdf-9643-417f-9974-ad72cae0e10f"

# Webex Teams Bot email address for this Bot 
TEAMS_BOT_EMAIL = "mybot@webex.bot"

# Webex Teams Bot email address for this Bot 
TEAMS_BOT_APP_NAME = "My Bot"

# Webex Teams user email who can access our bot
TEAMS_EMAILS = ["somebody@google.com"]

# For meraki SDK to connect to a Dahsboard account
MERAKI_API_KEY = '99NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN90'
